pub enum ReaderErrorKind {
Read(ErrorKind),
BufferTooSmall,
Eof,
InvalidRgb,
}Expand description
The specific reader error kind, shared by text and binary TokenReaders.
Variants
Read(ErrorKind)
An underlying error from a Reader
BufferTooSmall
The internal buffer does not have enough room to store data for the next token
Eof
An early end of the data encountered
InvalidRgb
The binary data is corrupted (invalid RGB token)